[gnome-bluetooth] Bug 588618 – Use PIN instead of passkey



commit be55bf228d5f5ce0e61626e03c76cdc9c45f8514
Author: Bastien Nocera <hadess hadess net>
Date:   Wed Jul 15 14:40:37 2009 +0100

    Bug 588618 â?? Use PIN instead of passkey
    
    Because people don't know what a passkey is.

 applet/agent.c             |   52 ++++++++++++++++++--------------
 applet/confirm-dialogue.ui |    2 +-
 applet/passkey-dialogue.ui |    2 +-
 applet/test-agentdialog.c  |    2 +-
 wizard/TEST-PROCEDURE.txt  |    6 ++--
 wizard/main.c              |   70 ++++++++++++++++++++++----------------------
 wizard/wizard.ui           |   32 ++++++++++----------
 7 files changed, 86 insertions(+), 80 deletions(-)
---
diff --git a/applet/confirm-dialogue.ui b/applet/confirm-dialogue.ui
index 8b571e6..b11a81a 100644
--- a/applet/confirm-dialogue.ui
+++ b/applet/confirm-dialogue.ui
@@ -14,7 +14,7 @@
     <property name="skip_taskbar_hint">True</property>
     <property name="message_type">other</property>
     <property name="text">Device 'Foobar' wants to pair with this computer</property>
-    <property name="secondary_text">Please confirm whether the passkey '123456' matches the one on device 'Foobar' (AA:BB:CC:DD:EE:FF).</property>
+    <property name="secondary_text">Please confirm whether the PIN '123456' matches the one on device 'Foobar' (AA:BB:CC:DD:EE:FF).</property>
     <property name="image">image1</property>
     <child internal-child="vbox">
       <object class="GtkVBox" id="dialog-vbox1">
diff --git a/applet/passkey-dialogue.ui b/applet/passkey-dialogue.ui
index b9263e5..5560bcf 100644
--- a/applet/passkey-dialogue.ui
+++ b/applet/passkey-dialogue.ui
@@ -15,7 +15,7 @@
     <property name="message_type">other</property>
     <property name="buttons">ok-cancel</property>
     <property name="text">Device 'Foobar' wants to pair with this computer</property>
-    <property name="secondary_text">Please enter the passkey mentioned on device 'Foobar' (AA:BB:CC:DD:EE:FF).</property>
+    <property name="secondary_text">Please enter the PIN mentioned on device 'Foobar' (AA:BB:CC:DD:EE:FF).</property>
     <property name="image">image1</property>
     <child internal-child="vbox">
       <object class="GtkVBox" id="dialog-vbox1">
diff --git a/applet/test-agentdialog.c b/applet/test-agentdialog.c
index c276186..d2506d5 100644
--- a/applet/test-agentdialog.c
+++ b/applet/test-agentdialog.c
@@ -67,7 +67,7 @@ int main(int argc, char *argv[])
 			"/hci0/dev_11_22_33_44_55_66", "org.bluez.Device");
 
 	//display_dialog(adapter, device, "Test (00:11:22:33:44:55)", "123456", 0, NULL);
-	passkey_dialog(adapter, device, "Test", "'Test' (00:11:22:33:44:55)", FALSE, NULL);
+	pin_dialog(adapter, device, "Test", "'Test' (00:11:22:33:44:55)", FALSE, NULL);
 	confirm_dialog(adapter, device, "Test", "'Test' (00:11:22:33:44:55)", "123456", NULL);
 	auth_dialog(adapter, device, "Test", "'Test' (00:11:22:33:44:55)", "UUID", NULL);
 
diff --git a/wizard/TEST-PROCEDURE.txt b/wizard/TEST-PROCEDURE.txt
index 3a2647b..d8d3ead 100644
--- a/wizard/TEST-PROCEDURE.txt
+++ b/wizard/TEST-PROCEDURE.txt
@@ -6,12 +6,12 @@ To test out all of the combinations of the wizard:
    - "Setup complete" page
 
 2. Setup legacy pairing device with dynamic pincode (phone)
-   - "Passkey" page
+   - "PIN" page
    - "Finishing setup" page
    - "Setup complete" page
 
 3. As 2., but with failure: wrong PIN
-   - "Passkey page"
+   - "PIN page"
    - "Failure page"
 
 4. As 3., but with cancelled pairing on target side
@@ -23,7 +23,7 @@ To test out all of the combinations of the wizard:
 
 6. Setup SSP device with input (computer, phone)
   - "Connecting to" page
-  - "SSP passkey" page
+  - "SSP PIN" page
   - "Finishing setup" page
   - "Setup complete" page
 
diff --git a/wizard/main.c b/wizard/main.c
index f26541d..dab9393 100644
--- a/wizard/main.c
+++ b/wizard/main.c
@@ -94,11 +94,11 @@ static GtkWidget *page_summary = NULL;
 static GtkWidget *label_connecting = NULL;
 static GtkWidget *spinner_connecting = NULL;
 
-static GtkWidget *label_passkey = NULL;
-static GtkWidget *label_passkey_help = NULL;
+static GtkWidget *label_pin = NULL;
+static GtkWidget *label_pin_help = NULL;
 
-static GtkWidget *label_ssp_passkey_help = NULL;
-static GtkWidget *label_ssp_passkey = NULL;
+static GtkWidget *label_ssp_pin_help = NULL;
+static GtkWidget *label_ssp_pin = NULL;
 static GtkWidget *does_not_match_button = NULL;
 static GtkWidget *matches_button = NULL;
 
@@ -113,7 +113,7 @@ static GtkWidget *extra_config_frame = NULL;
 
 static BluetoothChooser *selector = NULL;
 
-static GtkWidget *passkey_dialog = NULL;
+static GtkWidget *pin_dialog = NULL;
 static GtkWidget *radio_auto = NULL;
 static GtkWidget *radio_0000 = NULL;
 static GtkWidget *radio_1111 = NULL;
@@ -128,7 +128,7 @@ void select_device_changed(BluetoothChooser *selector, const char *address, gpoi
 gboolean entry_custom_event(GtkWidget *entry, GdkEventKey *event);
 void set_user_pincode(GtkWidget *button);
 void toggle_set_sensitive(GtkWidget *button, gpointer data);
-void passkey_option_button_clicked (GtkButton *button, gpointer data);
+void pin_option_button_clicked (GtkButton *button, gpointer data);
 void entry_custom_changed(GtkWidget *entry);
 void restart_button_clicked (GtkButton *button, gpointer user_data);
 void does_not_match_cb (GtkButton *button, gpointer user_data);
@@ -235,7 +235,7 @@ matches_cb (GtkButton *button,
 static gboolean
 confirm_callback (DBusGMethodInvocation *context,
 		  DBusGProxy *device,
-		  guint passkey,
+		  guint pin,
 		  gpointer user_data)
 {
 	char *str, *label;
@@ -243,15 +243,15 @@ confirm_callback (DBusGMethodInvocation *context,
 	target_ssp = TRUE;
 	gtk_assistant_set_current_page (window_assistant, PAGE_SSP_SETUP);
 
-	gtk_widget_show (label_ssp_passkey_help);
-	label = g_strdup_printf (_("Please confirm that the passkey displayed on '%s' matches this one."),
+	gtk_widget_show (label_ssp_pin_help);
+	label = g_strdup_printf (_("Please confirm that the PIN displayed on '%s' matches this one."),
 				 target_name);
-	gtk_label_set_markup(GTK_LABEL(label_ssp_passkey_help), label);
+	gtk_label_set_markup(GTK_LABEL(label_ssp_pin_help), label);
 	g_free (label);
 
-	gtk_widget_show (label_ssp_passkey);
-	str = g_strdup_printf ("%d", passkey);
-	set_large_label (GTK_LABEL (label_ssp_passkey), str);
+	gtk_widget_show (label_ssp_pin);
+	str = g_strdup_printf ("%d", pin);
+	set_large_label (GTK_LABEL (label_ssp_pin), str);
 	g_free (str);
 
 	g_object_set_data (G_OBJECT(does_not_match_button), "context", context);
@@ -263,7 +263,7 @@ confirm_callback (DBusGMethodInvocation *context,
 static gboolean
 display_callback (DBusGMethodInvocation *context,
 		  DBusGProxy *device,
-		  guint passkey,
+		  guint pin,
 		  guint entered,
 		  gpointer user_data)
 {
@@ -273,7 +273,7 @@ display_callback (DBusGMethodInvocation *context,
 	target_ssp = TRUE;
 	gtk_assistant_set_current_page (window_assistant, PAGE_SSP_SETUP);
 
-	code = g_strdup_printf("%d", passkey);
+	code = g_strdup_printf("%d", pin);
 
 	if (entered > 0) {
 		GtkEntry *entry;
@@ -296,11 +296,11 @@ display_callback (DBusGMethodInvocation *context,
 		done = g_strdup ("");
 	}
 
-	gtk_widget_show (label_passkey_help);
+	gtk_widget_show (label_pin_help);
 
-	gtk_label_set_markup(GTK_LABEL(label_ssp_passkey_help), _("Please enter the following passkey:"));
+	gtk_label_set_markup(GTK_LABEL(label_ssp_pin_help), _("Please enter the following PIN:"));
 	text = g_strdup_printf("%s%s", done, code + entered);
-	set_large_label (GTK_LABEL (label_ssp_passkey), text);
+	set_large_label (GTK_LABEL (label_ssp_pin), text);
 	g_free(text);
 
 	g_free(done);
@@ -547,10 +547,10 @@ void prepare_callback (GtkWidget *assistant,
 		if (automatic_pincode == FALSE && target_ssp == FALSE) {
 			char *text;
 
-			text = g_strdup_printf (_("Please enter the following passkey on '%s':"), target_name);
-			gtk_label_set_markup(GTK_LABEL(label_passkey_help), text);
+			text = g_strdup_printf (_("Please enter the following PIN on '%s':"), target_name);
+			gtk_label_set_markup(GTK_LABEL(label_pin_help), text);
 			g_free (text);
-			set_large_label (GTK_LABEL (label_passkey), pincode);
+			set_large_label (GTK_LABEL (label_pin), pincode);
 		} else {
 			g_assert_not_reached ();
 		}
@@ -678,7 +678,7 @@ void
 entry_custom_changed (GtkWidget *entry)
 {
 	user_pincode = g_strdup (gtk_entry_get_text(GTK_ENTRY(entry)));
-	gtk_dialog_set_response_sensitive (GTK_DIALOG (passkey_dialog),
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (pin_dialog),
 					   GTK_RESPONSE_ACCEPT,
 					   gtk_entry_get_text_length (GTK_ENTRY (entry)) >= 1);
 }
@@ -693,7 +693,7 @@ toggle_set_sensitive (GtkWidget *button,
 	gtk_widget_set_sensitive(entry_custom, active);
 	/* When selecting another PIN, make sure the "Close" button is sensitive */
 	if (!active)
-		gtk_dialog_set_response_sensitive (GTK_DIALOG (passkey_dialog),
+		gtk_dialog_set_response_sensitive (GTK_DIALOG (pin_dialog),
 						   GTK_RESPONSE_ACCEPT, TRUE);
 }
 
@@ -724,7 +724,7 @@ set_user_pincode (GtkWidget *button)
 		if (entry != NULL) {
 			g_free (user_pincode);
 			user_pincode = g_strdup (gtk_entry_get_text(entry));
-			gtk_dialog_set_response_sensitive (GTK_DIALOG (passkey_dialog),
+			gtk_dialog_set_response_sensitive (GTK_DIALOG (pin_dialog),
 							   GTK_RESPONSE_ACCEPT,
 							   gtk_entry_get_text_length (entry) >= 1);
 		} else if (pin != NULL) {
@@ -797,7 +797,7 @@ select_device_changed (BluetoothChooser *selector,
 }
 
 void
-passkey_option_button_clicked (GtkButton *button,
+pin_option_button_clicked (GtkButton *button,
 			       gpointer data)
 {
 	GtkWidget *radio;
@@ -806,9 +806,9 @@ passkey_option_button_clicked (GtkButton *button,
 	oldpin = user_pincode;
 	user_pincode = NULL;
 
-	gtk_window_set_transient_for (GTK_WINDOW (passkey_dialog),
+	gtk_window_set_transient_for (GTK_WINDOW (pin_dialog),
 				      GTK_WINDOW (window_assistant));
-	gtk_window_present (GTK_WINDOW (passkey_dialog));
+	gtk_window_present (GTK_WINDOW (pin_dialog));
 
 	/* When reopening, try to guess where the pincode was set */
 	if (oldpin == NULL)
@@ -826,14 +826,14 @@ passkey_option_button_clicked (GtkButton *button,
 	if (radio == radio_custom)
 		gtk_entry_set_text (GTK_ENTRY (entry_custom), oldpin);
 
-	if (gtk_dialog_run (GTK_DIALOG (passkey_dialog)) != GTK_RESPONSE_ACCEPT) {
+	if (gtk_dialog_run (GTK_DIALOG (pin_dialog)) != GTK_RESPONSE_ACCEPT) {
 		g_free (user_pincode);
 		user_pincode = oldpin;
 	} else {
 		g_free (oldpin);
 	}
 
-	gtk_widget_hide(passkey_dialog);
+	gtk_widget_hide(pin_dialog);
 }
 
 static int
@@ -917,14 +917,14 @@ create_wizard (void)
 
 	/* Setup page */
 	page_setup = W("page_setup");
-	label_passkey_help = W("label_passkey_help");
-	label_passkey = W("label_passkey");
+	label_pin_help = W("label_pin_help");
+	label_pin = W("label_pin");
 
 	/* SSP Setup page */
 	page_ssp_setup = W("page_ssp_setup");
 	gtk_assistant_set_page_complete(assistant, page_ssp_setup, FALSE);
-	label_ssp_passkey_help = W("label_ssp_passkey_help");
-	label_ssp_passkey = W("label_ssp_passkey");
+	label_ssp_pin_help = W("label_ssp_pin_help");
+	label_ssp_pin = W("label_ssp_pin");
 	does_not_match_button = W("does_not_match_button");
 	matches_button = W("matches_button");
 
@@ -953,8 +953,8 @@ create_wizard (void)
 	if (pixbuf != NULL)
 		g_object_unref (pixbuf);
 
-	/* Passkey dialog */
-	passkey_dialog = W("passkey_dialog");
+	/* PIN dialog */
+	pin_dialog = W("pin_dialog");
 	radio_auto = W("radio_auto");
 	radio_0000 = W("radio_0000");
 	radio_1111 = W("radio_1111");
diff --git a/wizard/wizard.ui b/wizard/wizard.ui
index 81fd57d..f657d66 100644
--- a/wizard/wizard.ui
+++ b/wizard/wizard.ui
@@ -83,13 +83,13 @@
           </packing>
         </child>
         <child>
-          <object class="GtkButton" id="passkey_option_button">
-            <property name="label" translatable="yes">Passkey _options...</property>
+          <object class="GtkButton" id="pin_option_button">
+            <property name="label" translatable="yes">PIN _options...</property>
             <property name="visible">True</property>
             <property name="can_focus">True</property>
             <property name="receives_default">True</property>
             <property name="use_underline">True</property>
-            <signal name="clicked" handler="passkey_option_button_clicked"/>
+            <signal name="clicked" handler="pin_option_button_clicked"/>
           </object>
           <packing>
             <property name="expand">False</property>
@@ -165,11 +165,11 @@
         <property name="border_width">24</property>
         <property name="spacing">6</property>
         <child>
-          <object class="GtkLabel" id="label_passkey_help">
+          <object class="GtkLabel" id="label_pin_help">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="yalign">0</property>
-            <property name="label">Please enter the following passkey on 'Foobar':</property>
+            <property name="label">Please enter the following PIN on 'Foobar':</property>
             <property name="wrap">True</property>
           </object>
           <packing>
@@ -178,7 +178,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="label_passkey">
+          <object class="GtkLabel" id="label_pin">
             <property name="label">&lt;span font_desc="50" color="black" bgcolor="white"&gt;  123456  &lt;/span&gt;</property>
             <property name="use_markup">True</property>
             <property name="visible">True</property>
@@ -199,11 +199,11 @@
         <property name="border_width">24</property>
         <property name="spacing">6</property>
         <child>
-          <object class="GtkLabel" id="label_ssp_passkey_help">
+          <object class="GtkLabel" id="label_ssp_pin_help">
             <property name="visible">True</property>
             <property name="xalign">0</property>
             <property name="yalign">0</property>
-            <property name="label">Please confirm that the passkey displayed on 'Foobar' matches this one</property>
+            <property name="label">Please confirm that the PIN displayed on 'Foobar' matches this one</property>
             <property name="wrap">True</property>
           </object>
           <packing>
@@ -212,7 +212,7 @@
           </packing>
         </child>
         <child>
-          <object class="GtkLabel" id="label_ssp_passkey">
+          <object class="GtkLabel" id="label_ssp_pin">
             <property name="label">&lt;span font_desc="50" color="black" bgcolor="white"&gt;  123456  &lt;/span&gt;</property>
             <property name="use_markup">True</property>
           </object>
@@ -382,9 +382,9 @@
       </packing>
     </child>
   </object>
-  <object class="GtkDialog" id="passkey_dialog">
+  <object class="GtkDialog" id="pin_dialog">
     <property name="border_width">5</property>
-    <property name="title" translatable="yes">Passkey Options</property>
+    <property name="title" translatable="yes">PIN Options</property>
     <property name="destroy_with_parent">True</property>
     <property name="type_hint">normal</property>
     <property name="has_separator">False</property>
@@ -401,7 +401,7 @@
             <property name="spacing">6</property>
             <child>
               <object class="GtkRadioButton" id="radio_auto">
-                <property name="label" translatable="yes">_Automatic passkey selection</property>
+                <property name="label" translatable="yes">_Automatic PIN selection</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
                 <property name="receives_default">False</property>
@@ -418,7 +418,7 @@
               <object class="GtkLabel" id="label1">
                 <property name="visible">True</property>
                 <property name="xalign">0</property>
-                <property name="label" translatable="yes">Fixed Passkey</property>
+                <property name="label" translatable="yes">Fixed PIN</property>
                 <attributes>
                   <attribute name="weight" value="bold"/>
                 </attributes>
@@ -478,7 +478,7 @@
                 <property name="spacing">12</property>
                 <child>
                   <object class="GtkRadioButton" id="radio_custom">
-                    <property name="label" translatable="yes">Custom passkey code:</property>
+                    <property name="label" translatable="yes">Custom PIN code:</property>
                     <property name="visible">True</property>
                     <property name="can_focus">True</property>
                     <property name="receives_default">False</property>
@@ -576,7 +576,7 @@
     <signal name="clicked" handler="restart_button_clicked"/>
   </object>
   <object class="GtkButton" id="does_not_match_button">
-    <property name="label" comments="This is a button to answer: Does the passkey matches the one on the device?" translatable="yes">Does not match</property>
+    <property name="label" comments="This is a button to answer: Does the PIN matches the one on the device?" translatable="yes">Does not match</property>
     <property name="visible">True</property>
     <property name="can_focus">True</property>
     <property name="receives_default">True</property>
@@ -585,7 +585,7 @@
     <signal name="clicked" handler="does_not_match_cb"/>
   </object>
   <object class="GtkButton" id="matches_button">
-    <property name="label" comments="This is a button to answer: Does the passkey matches the one on the device?" translatable="yes">Matches</property>
+    <property name="label" comments="This is a button to answer: Does the PIN matches the one on the device?" translatable="yes">Matches</property>
     <property name="visible">True</property>
     <property name="can_focus">True</property>
     <property name="receives_default">True</property>



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/applet/agent.c b/applet/agent.c
index 1f6dd44..09c85f9 100644
--- a/applet/agent.c
+++ b/applet/agent.c
@@ -81,7 +81,7 @@ static void input_free(input_data *input)
 		disable_blinking();
 }
 
-static void passkey_callback(GtkWidget *dialog,
+static void pin_callback(GtkWidget *dialog,
 				gint response, gpointer user_data)
 {
 	input_data *input = user_data;
@@ -92,8 +92,8 @@ static void passkey_callback(GtkWidget *dialog,
 		text = gtk_entry_get_text(GTK_ENTRY(input->entry));
 
 		if (input->numeric == TRUE) {
-			guint passkey = atoi(text);
-			dbus_g_method_return(input->context, passkey);
+			guint pin = atoi(text);
+			dbus_g_method_return(input->context, pin);
 		} else {
 			dbus_g_method_return(input->context, text);
 		}
@@ -208,7 +208,7 @@ static void toggled_callback(GtkWidget *button, gpointer user_data)
 }
 
 static void
-passkey_dialog (DBusGProxy *adapter,
+pin_dialog (DBusGProxy *adapter,
 		DBusGProxy *device,
 		const char *name,
 		const char *long_name,
@@ -254,7 +254,7 @@ passkey_dialog (DBusGProxy *adapter,
 	g_free (str);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("Please enter the passkey mentioned on device %s."),
+						  _("Please enter the PIN mentioned on device %s."),
 						  long_name);
 
 	entry = GTK_WIDGET (gtk_builder_get_object (xml, "entry"));
@@ -285,7 +285,7 @@ passkey_dialog (DBusGProxy *adapter,
 	input_list = g_list_append(input_list, input);
 
 	g_signal_connect (G_OBJECT (dialog), "response",
-			  G_CALLBACK (passkey_callback), input);
+			  G_CALLBACK (pin_callback), input);
 
 	enable_blinking();
 }
@@ -336,7 +336,7 @@ confirm_dialog (DBusGProxy *adapter,
 
 	str = g_strdup_printf ("<b>%s</b>", value);
 	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog),
-						    _("Please confirm whether the passkey '%s' matches the one on device %s."),
+						    _("Please confirm whether the PIN '%s' matches the one on device %s."),
 						    str, long_name);
 	g_free (str);
 
@@ -481,7 +481,7 @@ static gboolean pincode_request(DBusGMethodInvocation *context,
 	if (name == NULL)
 		return FALSE;
 
-	passkey_dialog(adapter, device, name, long_name, FALSE, context);
+	pin_dialog(adapter, device, name, long_name, FALSE, context);
 
 	g_free (long_name);
 
@@ -498,7 +498,7 @@ static gboolean pincode_request(DBusGMethodInvocation *context,
 	g_free(name);
 
 	show_notification(_("Bluetooth device"),
-			  line, _("Enter passkey"), 0,
+			  line, _("Enter PIN"), 0,
 			  G_CALLBACK(notification_closed));
 
 	g_free(line);
@@ -506,7 +506,7 @@ static gboolean pincode_request(DBusGMethodInvocation *context,
 	return TRUE;
 }
 
-static gboolean passkey_request(DBusGMethodInvocation *context,
+static gboolean pin_request(DBusGMethodInvocation *context,
 					DBusGProxy *device, gpointer user_data)
 {
 	DBusGProxy *adapter = user_data;
@@ -516,7 +516,7 @@ static gboolean passkey_request(DBusGMethodInvocation *context,
 	if (name == NULL)
 		return FALSE;
 
-	passkey_dialog(adapter, device, name, long_name, TRUE, context);
+	pin_dialog(adapter, device, name, long_name, TRUE, context);
 
 	g_free (long_name);
 
@@ -533,7 +533,7 @@ static gboolean passkey_request(DBusGMethodInvocation *context,
 	g_free(name);
 
 	show_notification(_("Bluetooth device"),
-			  line, _("Enter passkey"), 0,
+			  line, _("Enter PIN"), 0,
 			  G_CALLBACK(notification_closed));
 
 	g_free(line);
@@ -541,9 +541,12 @@ static gboolean passkey_request(DBusGMethodInvocation *context,
 	return TRUE;
 }
 
-static gboolean display_request(DBusGMethodInvocation *context,
-				DBusGProxy *device, guint passkey,
-					guint entered, gpointer user_data)
+static gboolean
+display_request (DBusGMethodInvocation *context,
+		 DBusGProxy *device,
+		 guint pin,
+		 guint entered,
+		 gpointer user_data)
 {
 	g_warning ("Not implemented, please file a bug at how this happened");
 	return FALSE;
@@ -555,7 +558,7 @@ static gboolean display_request(DBusGMethodInvocation *context,
 	if (name == NULL)
 		return FALSE;
 
-	text = g_strdup_printf("%d", passkey);
+	text = g_strdup_printf("%d", pin);
 	display_dialog(adapter, device, address, name, text, entered, context);
 	g_free(text);
 
@@ -572,7 +575,7 @@ static gboolean display_request(DBusGMethodInvocation *context,
 	g_free(name);
 
 	show_notification(_("Bluetooth device"),
-			  line, _("Enter passkey"), 0,
+			  line, _("Enter PIN"), 0,
 			  G_CALLBACK(notification_closed));
 
 	g_free(line);
@@ -581,8 +584,11 @@ static gboolean display_request(DBusGMethodInvocation *context,
 #endif
 }
 
-static gboolean confirm_request(DBusGMethodInvocation *context,
-			DBusGProxy *device, guint passkey, gpointer user_data)
+static gboolean
+confirm_request (DBusGMethodInvocation *context,
+		 DBusGProxy *device,
+		 guint pin,
+		 gpointer user_data)
 {
 	DBusGProxy *adapter = user_data;
 	char *name, *long_name, *line, *text;
@@ -591,7 +597,7 @@ static gboolean confirm_request(DBusGMethodInvocation *context,
 	if (name == NULL)
 		return FALSE;
 
-	text = g_strdup_printf("%d", passkey);
+	text = g_strdup_printf("%d", pin);
 	confirm_dialog(adapter, device, name, long_name, text, context);
 	g_free(text);
 
@@ -606,11 +612,11 @@ static gboolean confirm_request(DBusGMethodInvocation *context,
 	/* translators:
 	 * This message is for Bluetooth 2.1 support, when the
 	 * action is clicked in the notification popup, the user
 	 * will get to check whether the passkey matches the one
 	 * showing on the Bluetooth device */
 	if (notification_supports_actions () != FALSE)
 		show_notification(_("Bluetooth device"),
-				    line, _("Verify passkey"), 0,
+				    line, _("Verify PIN"), 0,
 				    G_CALLBACK(notification_closed));
 	else
 		present_notification_dialogs ();
@@ -703,7 +709,7 @@ static gboolean adapter_insert(GtkTreeModel *model, GtkTreePath *path,
 	agent = bluetooth_agent_new();
 
 	bluetooth_agent_set_pincode_func(agent, pincode_request, adapter);
-	bluetooth_agent_set_passkey_func(agent, passkey_request, adapter);
+	bluetooth_agent_set_passkey_func(agent, pin_request, adapter);
 	bluetooth_agent_set_display_func(agent, display_request, adapter);
 	bluetooth_agent_set_confirm_func(agent, confirm_request, adapter);
 	bluetooth_agent_set_authorize_func(agent, authorize_request, adapter);
@@ -606,11 +612,11 @@ static gboolean confirm_request(DBusGMethodInvocation *context,
 	 * This message is for Bluetooth 2.1 support, when the
 	 * action is clicked in the notification popup, the user
-	 * will get to check whether the passkey matches the one
+	 * will get to check whether the PIN matches the one
 	 * showing on the Bluetooth device */
 	if (notification_supports_actions () != FALSE)